# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1494
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


import unittest

from visier_api_analytic_model.api.data_model_api import DataModelApi


class TestDataModelApi(unittest.TestCase):
    """DataModelApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DataModelApi()

    def tearDown(self) -> None:
        pass

    def test_analytic_metrics(self) -> None:
        """Test case for analytic_metrics

        Retrieve a list of metrics for an analytic object by ID
        """
        pass

    def test_analytic_object(self) -> None:
        """Test case for analytic_object

        Retrieve an analytic object by ID
        """
        pass

    def test_analytic_objects(self) -> None:
        """Test case for analytic_objects

        Retrieve a list of analytic objects
        """
        pass

    def test_call_property(self) -> None:
        """Test case for call_property

        Retrieve a property by ID
        """
        pass

    def test_currencies(self) -> None:
        """Test case for currencies

        Retrieve all currencies
        """
        pass

    def test_currency(self) -> None:
        """Test case for currency

        Retrieve a currency
        """
        pass

    def test_currency_rates(self) -> None:
        """Test case for currency_rates

        Retrieve all exchange rates for a currency
        """
        pass

    def test_currency_rates_with_to_currency(self) -> None:
        """Test case for currency_rates_with_to_currency

        Retrieve exchange rates from one currency to another currency
        """
        pass

    def test_dimension(self) -> None:
        """Test case for dimension

        Retrieve a dimension by ID
        """
        pass

    def test_dimension_member_map_validation(self) -> None:
        """Test case for dimension_member_map_validation

        Validate a member map's unmapped dimension members by ID
        """
        pass

    def test_dimensions(self) -> None:
        """Test case for dimensions

        Retrieve a list of dimensions
        """
        pass

    def test_member(self) -> None:
        """Test case for member

        Retrieve a dimension member
        """
        pass

    def test_members(self) -> None:
        """Test case for members

        Retrieve a list of dimension members
        """
        pass

    def test_metric(self) -> None:
        """Test case for metric

        Retrieve a metric by ID
        """
        pass

    def test_metric_dimensions(self) -> None:
        """Test case for metric_dimensions

        Retrieve a metric's dimensions
        """
        pass

    def test_metric_selection_concepts(self) -> None:
        """Test case for metric_selection_concepts

        Retrieve a metric's selection concepts
        """
        pass

    def test_metrics(self) -> None:
        """Test case for metrics

        Retrieve a list of metrics
        """
        pass

    def test_planning_metrics(self) -> None:
        """Test case for planning_metrics

        Retrieve metrics by planning model ID
        """
        pass

    def test_planning_model(self) -> None:
        """Test case for planning_model

        Retrieve a planning model by ID
        """
        pass

    def test_planning_models(self) -> None:
        """Test case for planning_models

        Retrieve a list of planning models
        """
        pass

    def test_planning_plan(self) -> None:
        """Test case for planning_plan

        Retrieve a plan by ID
        """
        pass

    def test_planning_plans(self) -> None:
        """Test case for planning_plans

        Retrieve a list of plans
        """
        pass

    def test_prediction(self) -> None:
        """Test case for prediction

        Retrieve a prediction by ID
        """
        pass

    def test_predictions(self) -> None:
        """Test case for predictions

        Retrieve a list of predictions
        """
        pass

    def test_properties(self) -> None:
        """Test case for properties

        Retrieve a list of properties
        """
        pass

    def test_selection_concept(self) -> None:
        """Test case for selection_concept

        Retrieve an analytic object's selection concept by ID
        """
        pass

    def test_selection_concepts(self) -> None:
        """Test case for selection_concepts

        Retrieve an analytic object's selection concepts
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Analytic Model APIs

    Visier APIs for retrieving and configuring your analytic model in Visier.

    The version of the OpenAPI document: 22222222.99201.1494
    Contact: alpine@visier.com

    Please note that this SDK is currently in beta.
    Functionality and behavior may change in future releases.
    We encourage you to provide feedback and report any issues encountered during your use.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "visier-api-analytic-model"
VERSION = "0.99201.1494.beta4"
PYTHON_REQUIRES = ">=3.8"
REQUIRES = [
    "visier-api-core ~= 0.99201.1494.beta4",
]

setup(
    name=NAME,
    version=VERSION,
    description="Visier Analytic Model APIs",
    author="Visier",
    author_email="alpine@visier.com",
    url="",
    keywords=["Visier", "Visier-SDK", "Visier Analytic Model APIs"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache License, Version 2.0",
    long_description_content_type='text/markdown',
    long_description="""\
    Visier APIs for retrieving and configuring your analytic model in Visier.
    """,  # noqa: E501
    package_data={"visier_api_analytic_model": ["py.typed"]},
)
